@@ -2,7 +2,7 @@ import numpy as np
 from scipy.interpolate import RectBivariateSpline
 
 
-__version__ = '1.0.5'
+__version__ = '1.0.7'
 
 class CoeffTable:
     """ CoeffTable class for aerodynamic coefficients """
@@ -110,13 +110,13 @@ class C81:
         if not self._isIncreasing(self.CL.mach):
             raise ValueError('mach CL should be strictly increasing')
         if not self._isIncreasing(self.CD.alpha):
-            raise ValueError('alpha CL should be strictly increasing')
+            raise ValueError('alpha CD should be strictly increasing')
         if not self._isIncreasing(self.CD.mach):
-            raise ValueError('mach CL should be strictly increasing')
+            raise ValueError('mach CD should be strictly increasing')
         if not self._isIncreasing(self.CM.alpha):
-            raise ValueError('alpha CL should be strictly increasing')
+            raise ValueError('alpha CM should be strictly increasing')
         if not self._isIncreasing(self.CM.mach):
-            raise ValueError('mach CL should be strictly increasing')
+            raise ValueError('mach CM should be strictly increasing')
 
         self._interpCL = RectBivariateSpline( self.CL.alpha, self.CL.mach, \
                                             self.CL.val, kx=1, ky=1)
@@ -211,7 +211,7 @@ def load(fileObject):
     nalpha_M = int(header[40:42])
 
     # LIFT
-    multilinedata = nmach_l >= 9
+    multilinedata = nmach_l > 9
     # Read mach values
     mach_l = fileObject.readline().rstrip()
     if multilinedata:
@@ -229,7 +229,7 @@ def load(fileObject):
         CL = CL + [line[1:]]
 
     # DRAG
-    multilinedata = nmach_d >= 9
+    multilinedata = nmach_d > 9
     # Read mach values
     mach_d = fileObject.readline().rstrip()
     if multilinedata:
@@ -247,7 +247,7 @@ def load(fileObject):
         CD = CD + [line[1:]]
 
     # MOMENT
-    multilinedata = nmach_m >= 9
+    multilinedata = nmach_m > 9
     # Read mach values
     mach_m = fileObject.readline().rstrip()
     if multilinedata:
